# Generated by roxygen2: do not edit by hand

S3method(coef,mixturecure)
S3method(dim,mixturecure)
S3method(family,mixturecure)
S3method(formula,mixturecure)
S3method(logLik,mixturecure)
S3method(nobs,mixturecure)
S3method(plot,mixturecure)
S3method(predict,mixturecure)
S3method(print,mixturecure)
S3method(summary,mixturecure)
export(auc_mcm)
export(concordance_mcm)
export(cure_estimate)
export(cureem)
export(curegmifs)
export(cv_cureem)
export(cv_curegmifs)
export(generate_cure_data)
export(nonzerocure_test)
export(sufficient_fu_test)
import(doParallel)
import(flexsurv)
import(flexsurvcure)
import(foreach)
import(ggplot2)
import(glmnet)
import(graphics)
import(knockoff)
import(mvnfast)
import(parallel)
import(plyr)
import(stats)
import(survival)
importFrom(ggpubr,ggarrange)
importFrom(methods,is)
importFrom(utils,head)
